@@ -63,7 +63,7 @@ class DiscreteEnv(gym.Env):
     self.state=None    #self.df.sample(n=1, random_state=1).values.reshape(3,)
 
     #introduce some (short) length (time steps)
-    self.horizon=40
+    self.horizon=200
     
     
 
@@ -127,10 +127,10 @@ class DiscreteEnv(gym.Env):
     self.horizon = 200
     
     self.dfa = pd.DataFrame(dict(
-            Xs=truncnorm.rvs(a=0, b= math.inf,size=self.size),
-            Xa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
-            Y=np.random.binomial(1, 0.5, self.size)))
-    self.model = LogisticRegression().fit(self.dfa[["Xs", "Xa"]], np.ravel(self.dfa[["Y"]].astype(int)))
+            Xsa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
+            Xaa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
+            Ya=np.random.binomial(1, 0.5, self.size)))
+    self.model = LogisticRegression().fit(self.dfa[["Xsa", "Xaa"]], np.ravel(self.dfa[["Ya"]].astype(int)))
 
     #extract theta parameters from the fitted logistic
     self.thetasa = np.array([self.modela.coef_[0,0] , self.modela.coef_[0,1], self.modela.intercept_[0]]) #thetas[1] coef for Xs, thetas[2] coef for Xa
